/* Algeria FLFP ECE
Descriptives
Version 10 CK
Original: November 24, 2019
Updated: 2023.02.16 (WBER Revision)
Moundir Lassassi and Caroline Krafft
*/

*Comparing 2006,  2012, 2018
use "Data & Do/combo 2006 2012 2018.dta", clear


******
*Emp by youngest
******

preserve

collapse emp if age>=15 & age<=64 & sex==2 [pweight=hhweight], by(year agecat_young)

drop if agecat_young==.

#delimit ;
graph hbar emp , asyvars
	over(year) over(agecat_young) blabel(bar, format(%9.0f) size(3))
	bar(1, lcolor(gs12) fcolor(gs12))
	bar(2, lcolor(gs8) fcolor(gs8))
	bar(3, lcolor(gs4) fcolor(gs4))
	bar(4, lcolor(gs1) fcolor(gs1))
	ylabel(0 (10) 60, labs(medium) nogrid) ytitle("Employment rate (percentage)", size(3.5))  
	title("", size(4)) legend(rows(1) size(4) )
	scheme(s1mono);
	#delimit cr

graph save "Graphs and tables/emp by youngest.gph", replace
graph export "Graphs and tables/emp by youngest.png",  replace width(3000)

restore

******
*Hours 
******
                                               
preserve


table year if ece!=. [aw=chweight], c(mean hrs_ece median hrs_ece)
table year sit if ch_ece_4==100 [aw=hhweight], c(mean ch_hrs_ece_4 median ch_hrs_ece_4)

recode sit (2=3)

bysort sit: sum ch_hrs_ece_4 if ch_ece_4==100 [aw=hhweight], detail

tabu ch_hrs_ece_4 sit if ch_ece_4==100 [aw=hhweight], col nofreq

#delimit ;
graph twoway kdensity ch_hrs_ece_4 [aw=hhweight] if sit==1, lcolor(gs1) bw(3) ||  kdensity  ch_hrs_ece_4 [aw=hhweight] if sit==3, xaxis(1 2) bw(3)
	xlabel(0 (10) 40, labs(medium) nogrid) xtitle("Hours per week of pre-primary", size(3.5) axis(2)) xtitle("",axis(1)) 
	title("", size(4)) legend(rows(1) size(4) label(1 "Employed") label(2 "Non-employed")) ytitle("Density") plotregion(margin(zero)) xline(21, lcolor(black) lpatt(dash)) xlabel(21 "Public preparatory", axis(1)) ylabel(0(.01).05) xlabel(0(10)56, axis(2))
	scheme(s1mono);
	#delimit cr

graph save "Graphs and tables/hours by youngest.gph", replace
graph export "Graphs and tables/hours by youngest.png",  replace width(3000)

restore

******
*Sample characteristics 
******


*Descriptives on ece
tabout educ agegrp2 marital nuclear urban region year [aw=hhweight] if ch_ece_4!=. using "Graphs and Tables/Desc enroll.xls", sum replace c(mean ch_ece_4) npos(row)

tabout educ agegrp2 marital nuclear urban region year [aw=hhweight] if ch_ece_5!=. using "Graphs and Tables/Desc enroll.xls", sum replace c(mean ch_ece_5) npos(row)



foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {


iebaltab ed_* age_4 age_5 age_6 age_7 age_8 age_9 age_10 age_11 age_12 age_13 age_14 mar_* nuclear urban reg_* if year==`time' [aw=hhweight], grpvar(qual_`group') save("Graphs and tables/balance_`group'_`time'") replace starlevels(.05 .01 .001) rowlabel("ed_1 No education @ ed_2 Primary @ ed_3 Middle @ed_4 Secondary @ ed_5 Tertiary @ age_4 Age 15-19 @ age_5 Age 20-24 @ age_6 Age 25-29 @ age_7 Age 30-34 @ age_8 Age 35-39 @ age_9 Age 40-45 @ age_10 Age 45-49 @ age_11 Age 50-54 @ age_12 Age 55-59 @ age_13 Age 60-64 @ age_14 Age 65-69 @ mar_1 Single @ mar_2 Marired @ mar_3 Divorced @ mar_4 Widowed @ nuclear Nuclear household @ urban Urban @ reg_1 North Center @ reg_2 North East @ reg_3 North West @ reg_4 High Central Plains @ reg_5 High East Plains @ reg_6 High West Plains @ reg_7 South") ftest fmissok

}
}


