/* Algeria FLFP ECE
MICS 2006 data prep
Version 7 CK
Original: November 18, 2019
Updated: 2023.03.17 (WBER revision)
Moundir Lassassi and Caroline Krafft
*/


*Use the household level file 
use "Original data/2006/Ménages.dta", clear 

*Lower case
rename *, lower

*Identifier
isid hh1 hh2
*Yes
codebook hh1 hh2


*Generate a household id
gen hhid="06"+string(hh1, "%03.0f")+string(hh2, "%02.0f")
isid hhid 

*Drop prev. 
drop region_17 top 

save "Data & Do/hh 2006.dta", replace

*Use the child level file 
use "Original data/2006/Child.dta", clear 

*Lower case
rename *, lower

*Identifier
isid hh1 hh2 ln
*Yes
codebook hh1 hh2 ln


*Generate a household id
gen hhid="06"+string(hh1, "%03.0f")+string(hh2, "%02.0f")
isid hhid ln

*Generate an individual id
gen indid=hhid+string(ln, "%02.0f")
isid indid


*Drop prev. 
drop ece

save "Data & Do/ch 2006.dta", replace

*Use the member-level file
use "Original data/2006/Membres du ménage_MICS3.dta", clear 

*Lower case
rename *, lower

*Drop previous versions
drop elevel hand age_1 memage g_age_mc hyp diab card asthme artic autr_mc age_3 region_17 age mage mline fline act_mere act_pere sit_mere sit_pere


*Identifier
isid hh1 hh2 hl1
*Yes
codebook hh1 hh2 hl1

*Generate a household id
gen hhid="06"+string(hh1, "%03.0f")+string(hh2, "%02.0f")
isid hhid hl1

la var hhid "Unique household id"


*Generate an individual id
gen indid=hhid+string(hl1, "%02.0f")
isid indid

la var indid "Unique individual id"


*Merge together the household and member data
merge m:1 hhid using "Data & Do/hh 2006.dta"

tabu _merge
drop if _merge==2
*Non-response
drop _merge


*Merge together the household member and child data
merge 1:1 indid using "Data & Do/ch 2006.dta"

tabu _merge
drop _merge

***ECE for ages 3-4
tabu br6

*If report no prescolaire
gen ece=0 if br6==2 & hl5>=3 & hl5<=4
*If report prescolaire
replace ece=1 if br6==1  & hl5>=3 & hl5<=4

***ece for age 5/6
*Attend in 2005/6
fre ed4
*Level in 2005/6
fre ed6a

*If not currently enrolled and eligible (should not be in primary in 2005-2006 school year)
replace ece=0 if ed4==2 & (hl5==5 | hl5==6)
*If currently enrolled in preschool
replace ece=1 if ed4==1 & ed6a==0 & (hl5==5 | hl5==6)
*Missing if should be in primary (born 1999 or earlier)
replace ece=. if hl5y<=1999 | hl5y==9999 | hl5y==9998

la var ece "Attends ECE"

tabu hl5 ece

tabu ed4 ed6a if hl5>=3 & hl5<=6 & ece==., miss
tabu br6 if hl5>=3 & hl5<=4 & ece==., miss

*** Hours ece
fre br7

gen hrs_ece=br7 if br7!=99 & ece==1 

la var hrs_ece "Hours of pre-primary per week"

***Current primarys as zeroes
*Same to start
gen ece_z=ece
*Add current primary as zeroes
replace ece_z=0 if ed4==1 & ed6a==1 & (hl5==5 | hl5==6)
*Missing if should be in primary (born 1999 or earlier)
replace ece_z=. if hl5y<=1999 | hl5y==9999 | hl5y==9998

*Nuclear household
egen max_rel=max(hl3), by(hhid)

gen nuclear=0 if max_rel>3 & max_rel<.
replace nuclear=1 if max_rel<=3

la def Lnuclear 0 "Extended" 1 "Nuclear"
la var nuclear "Household structure"
la val nuclear Lnuclear

*Labor market status
recode ac2 (1=1)(2=2)(4=3)(5=3)(6=3)(7=3) (9=.), gen(sit)

label variable sit "Situation individuelle"
label define Lsit 1 "Occupe" 
label define Lsit 2 "Chomeur", add
label define Lsit 3 "Inactive", add

label value sit Lsit, nofix

tabu sit hl4 if hl5>=15 & hl5<=64, miss
tabu hl5 sit, miss
*Missing primarily under15 

*Type of employment
gen self_emp=0 if sit!=.
replace self_emp=1 if inlist(ac3,1,2,6)

gen wage_emp=0 if sit!=.
replace wage_emp=1 if inlist(ac3,3,4,5)


*Adult education
fre ed3a

recode ed3a (0=2) (1=2) (2=3) (3=4) (4=5) (9=.), gen(educ)

replace educ=1 if ed2==2

la def Leduc 1 "None" 2 "Primary" 3 "Middle" 4 "Secondary" 5 "Tertiary" 
la var educ "Education level"


la val educ Leduc
fre educ
tabu hl5 educ, miss
*Missing primarily children

*Sex
clonevar sex=hl4

*Marital status
recode hl5b (1=1 "Single")(2=2 "Married")(3=3 "Divorced")(4=4 "Widowed")(9=.), gen(marital) label(Lmarital)

label variable marital "Marital status"


*Age 
gen age=hl5 if hl5!=98

la var age "Age"

*Birthdate
gen birthy=hl5y if hl5y<=2006
gen birthm=hl5m if hl5m<=12
gen birthd=hl5d if hl5d<=31

la var birthy "Birth year"
la var birthm "Birth month"
la var birthd "Birth day"

*Visit date
gen visity=hh5y if hl5y<=2006
gen visitm=hh5m if hl5m<=12
gen visitd=hh5d if hl5d<=31

la var visity "Visit year"
la var visitm "Visit month"
la var visitd "Visit day"

gen year=2006

*Create age on December 31 (centered at zero for each age)
*Taking six months on either side as analysis sample for each age

gen birth_date=mdy(birthm,birthd,birthy)
format birth_date %td

gen visit_date=mdy(visitm,visitd,visity)
format visit_date %td

*Six months is July 1 the current year to June 31 the following year
gen personal_d31=mdy(12,31,birthy)
replace personal_d31=mdy(12,31,birthy-1) if birthm<=6
*format personal_d31 %td

*Age on December 31
gen age_d31=floor((mdy(12,31,2005)-birth_date)/365) if year==2006

tabu age_d31 ece, miss

replace age_d31=. if age_d31<0
*Only for age 4-5
replace ece=. if age_d31<3 | age_d31>5
replace ece_z=. if age_d31<3 | age_d31>5

gen days_d31=personal_d31-birth_date

tabu days_d31

tabu days_d31 age_d31 if age_d31<=5

la var days_d31 "Days older than December 31 cutoff"

*RD Group
gen rd_group=. 
replace rd_group=5 if year==2006 & personal_d31==14975
replace rd_group=4 if year==2006 & personal_d31==15340


la def Lrd_group 4 "Age 4 cutoff" 5 "Age 5 cutoff"
la val rd_group Lrd_group
la var rd_group "Groups for RDD"

tabu rd_group year
table age rd_group year
tabu age_d31 rd_group 

tabu rd_group ece, miss
tabu age if rd_group==. & ece!=.

tabu ece ece_z if rd_group==4, miss
tabu ece ece_z if rd_group==5, miss

*Urban/rural
clonevar urban=hh6

*Region
gen region=1 if inlist(hh1a,16,9,42,35,10,26,15,6,2,44) 
replace region=2 if inlist(hh1a,23,25,21,18,43,41,36,24)
replace region=3 if inlist(hh1a,31,13,27,46,48,22,29)
replace region=4 if inlist(hh1a,17,3,28)
replace region=5 if inlist(hh1a,19,5,40,34,4,12)
replace region=6 if inlist(hh1a,14,20,38,45,32)
replace region=7 if inlist(hh1a,8,37,1,47,7,39,30,11,33)


*Wealth index
xtile hhwealth=wlthscor if hl1==1 [aw=hhweight], n(5)
egen qwealth=max(hhwealth), by(hhid)

la var qwealth "Household wealth quintile"

la def Lqwealth 1 "Poorest" 2 "Poor" 3 "Middle" 4 "Richer" 5 "Richest"

la val qwealth Lqwealth

*Weights
*HH weight at age 5
replace chweight=hhweight if age==5 | age==6

save "Data & Do/hl ch 2006.dta", replace


*Family composition
use "Data & Do/hl ch 2006.dta", clear

drop indid

tabu hl10, miss
keep if hl10!=.


*Generate an individual id of the mother
gen indid=hhid+string(hl10, "%02.0f")

collapse (min) yng_age=age, by(indid)


save "Data & Do/mere_all_ch 2006.dta", replace

use "Data & Do/hl ch 2006.dta", clear

*Youngest ECE eligible attends?
keep if ece!=. & rd_group!=.
drop indid

*Generate an individual id of the mother
gen indid=hhid+string(hl10, "%02.0f")

*Take data from youngest if multiple
sort indid rd_group birth_date

*Youngest will be last
bysort indid rd_group: keep if _n==_N
*Drops 56 obs.

*Unique?
isid rd_group indid

*Keep 
keep ece age_d31 days_d31 rd_group hrs_ece indid
rename * ch_*_
rename ch_indid_ indid

*Reshape 
reshape wide ch_ece_ ch_age_d31 ch_days_d31 ch_hrs_ece, j(ch_rd_group) i(indid) 

save "Data & Do/mere_ch 2006.dta", replace

*ALT Youngest ECE eligible attends?
use "Data & Do/hl ch 2006.dta", clear

keep if ece_z!=. & rd_group!=.
drop indid

*Generate an individual id of the mother
gen indid=hhid+string(hl10, "%02.0f")

*Take data from youngest if multiple
sort indid rd_group birth_date

*Youngest will be last
bysort indid rd_group: keep if _n==_N
*Drops 58 obs.

*Unique?
isid rd_group indid

*Keep 
keep ece_z age_d31 days_d31 rd_group hrs_ece indid
rename * ch_*_z_
rename *z_z* *z*
rename ch_indid_ indid

*Reshape 
reshape wide ch_ece_z_ ch_age_d31 ch_days_d31 ch_hrs_ece, j(ch_rd_group) i(indid) 

save "Data & Do/mere_ch_z 2006.dta", replace

*Merge into household file
use "Data & Do/hl ch 2006.dta", clear

*Merging based on mother's/guardian's line
merge 1:1 indid using "Data & Do/mere_ch 2006.dta"
tabu _merge 
tabu _merge hl4, miss
*Drop mis-match
drop if _merge==2
drop _merge

*Merging based on mother's/guardian's line
merge 1:1 indid using "Data & Do/mere_ch_z 2006.dta"
tabu _merge 
tabu _merge hl4, miss
*Drop mis-match
drop if _merge==2
drop _merge


*Merging based on mother's/guardian's line
merge 1:1 indid using "Data & Do/mere_all_ch 2006.dta"
tabu _merge 
tabu _merge hl4, miss
drop if _merge==2
drop _merge

*Keep for combining

keep yng_age ece hrs_ece age_d31 rd_group ch_ece* ch_hrs_ece* sit educ sex marital age urban hhid indid ///
chweight hhweight birth? qwealth visit? region nuclear ///
 melevel felevel year ch_days_d31* ch_age_d31* self_emp wage_emp helevel

foreach num of numlist 4/5 { 
 
la var ch_ece_z_`num' "Child in ECE alt. (age `num')"
la var ch_ece_`num' "Child in ECE (age `num')"
la var ch_hrs_ece_`num' "Child hours in ECE (age `num')"
la var ch_age_d31_`num' "Age of child Dec. 31 (age `num')"
la var ch_days_d31_`num' "Days from cutoff of child (age `num')"

}

save "Data & Do/combo 2006.dta", replace
