/* Algeria FLFP ECE
MICS 2018 data prep
Version 6 CK
Original: January 27, 2021
Updated: 2023.03.17 (WBER revision)
Moundir Lassassi and Caroline Krafft
*/


*Use the household level file 
import spss "Original data/2018 - 2019/hh.sav", clear 

*Lower case
rename *, lower


*Identifier
isid hh1 hh2
*Yes
codebook hh1 hh2


*Generate a household id
gen hhid="18"+string(hh1, "%04.0f")+string(hh2, "%02.0f")
isid hhid

save "Data & Do/hh 2018.dta", replace

*Use the child level file 
import spss "Original Data/2018 - 2019/ch.sav", clear 

*Lower case
rename *, lower

*Identifier
isid hh1 hh2 ln
*Yes
codebook hh1 hh2 ln


*Generate a household id
gen hhid="18"+string(hh1, "%04.0f")+string(hh2, "%02.0f")
isid hhid ln

*Generate an individual id
gen indid=hhid+string(ln, "%02.0f")
isid indid

save "Data & Do/ch 2018.dta", replace



*Use the person-level file
import spss "Original data/2018 - 2019/hl.sav", clear 

gen year=2018

*Lower case
rename *, lower

*Identifier
isid hh1 hh2 hl1
*Yes
codebook hh1 hh2 hl1

*Generate a household id
gen hhid="18"+string(hh1, "%04.0f")+string(hh2, "%02.0f")

*Identifier
isid hhid hl1

la var hhid "Unique household id"

*Generate an individual id
gen indid=hhid+string(hl1, "%02.0f")
isid indid

la var indid "Unique individual id"

*Merge together the household and member data
merge m:1 hhid using "Data & Do/hh 2018.dta"

tabu _merge
drop if _merge==2
*Non-response
drop _merge


*Merge together the household and child data
merge 1:1 indid using "Data & Do/ch 2018.dta"

tabu _merge
tabu hl6 _merge, miss
drop _merge

***ECE for ages 3+ 
* ed4 is current or past preschool/school
* ed9 is current preschool/school
* ed10a is current (2018/19) level


*If report never education or preschool
gen ece=0 if ed4==2 & hl6>=3 & hl6<=6
*If report not current education or preschool
replace ece=0 if ed4==1 & ed9==2 & hl6>=3 & hl6<=6
*If report prescolaire/nursery school currently
replace ece=1 if ed10a==0 & hl6>=3 & hl6<=6
*If 3-4 and currently in preschool
replace ece=1 if ub7==1 & hl6>=3 & hl6<=4
*Set to missing if should be in primary (born 2012)
replace ece=. if hl5y==9998 | hl5y==2012

la var ece "Attends ECE"

tabu hl6 ece, miss

*Check
tabu ed5a if hl6>=3 & hl6<=6 & ece==., miss

***Hours of ece - not collected

***Current primarys as zeroes
*Same to start
gen ece_z=ece
*Add current primary as zeroes
replace ece_z=0 if ed10a==1 & hl6>=3 & hl6<=6
*Missing if should be in primary (born 1999 or earlier)
replace ece_z=. if hl5y==9998 | hl5y==2012


*Nuclear household
egen max_rel=max(hl3), by(hhid)

gen nuclear=0 if max_rel>3 & max_rel<.
replace nuclear=1 if max_rel<=3

la def Lnuclear 0 "Extended" 1 "Nuclear"
la var nuclear "Household structure"
la val nuclear Lnuclear

*Labor market status
recode ae4 (1=1)(2=3)(3=2)(4=3)(5=3)(-99=.), gen(sit)

label variable sit "Situation individuelle"
label define Lsit 1 "Occupe" 
label define Lsit 2 "Chomeur", add
label define Lsit 3 "Inactive", add

label value sit Lsit, nofix

tabu sit hl4 if hl6>=15 & hl6<=64, miss

*Type of employment
gen self_emp=0 if sit!=.
replace self_emp=1 if ae5==2

gen wage_emp=0 if sit!=.
replace wage_emp=1 if ae5==1

*Adult education
fre ed5a

recode ed5a (0=1) (1=2) (2=3) (3=4) (4=5) (9=.) (8=.), gen(educ)

*None
replace educ=1 if ed4==2

la def Leduc 1 "None" 2 "Primary" 3 "Middle" 4 "Secondary" 5 "Tertiary" 

la val educ Leduc
fre educ
la var educ "Education level"

*Sex
clonevar sex=hl4

*Marital status
recode hl6b (1=1 "Single")(2=2 "Married")(3/4=3 "Divorced")(5=4 "Widowed"), gen(marital) label(Lmarital)

label variable marital "Marital status"

*Age 
gen age=hl6 if hl6!=98 & hl6!=99

la var age "Age"


*Birthdate
gen birthy=hl5y if hl5y<=2019
gen birthm=hl5m if hl5m<=12
gen birthd=hl5d if hl5d<=31

la var birthy "Birth year"
la var birthm "Birth month"
la var birthd "Birth day"



*Visit date
gen visity=hh5y if hl5y<=2019
gen visitm=hh5m if hl5m<=12
gen visitd=hh5d if hl5d<=31

la var visity "Visit year"
la var visitm "Visit month"
la var visitd "Visit day"


*Create age on December 31 (centered at zero for each age)
*Taking six months on either side as analysis sample for each age

gen birth_date=mdy(birthm,birthd,birthy)
format birth_date %td

gen visit_date=mdy(visitm,visitd,visity)
format visit_date %td

*Six months is July 1 the current year to June 31 the following year
gen personal_d31=mdy(12,31,birthy)
replace personal_d31=mdy(12,31,birthy-1) if birthm<=6
*format personal_d31 %td

gen age_d31=floor((mdy(12,31,2018)-birth_date)/365) if year==2018

tabu age_d31 ece, miss

replace age_d31=. if age_d31<0
*Keep age 4 and 5 groups
replace ece=. if age_d31<3 | age_d31>5
replace ece_z=. if age_d31<3 | age_d31>5

gen days_d31=personal_d31-birth_date

tabu days_d31

tabu days_d31 age_d31 if age_d31<=5

la var days_d31 "Days older than December 31 cutoff"

*RD Group
gen rd_group=. 
replace rd_group=5 if year==2018 & personal_d31==19723
replace rd_group=4 if year==2018 & personal_d31==20088


la def Lrd_group  4 "Age 4 cutoff" 5 "Age 5 cutoff"
la val rd_group Lrd_group
la var rd_group "Groups for RDD"

tabu rd_group year
table age rd_group year
tabu age_d31 rd_group , miss

tabu rd_group ece, miss
tabu age if rd_group==. & ece!=.

tabu ece ece_z if rd_group==4, miss
tabu ece ece_z if rd_group==5, miss


*Urban/rural
clonevar urban=hh6

*Region
clonevar region=hh7

*Wealth index
xtile hhwealth=wscore if hl1==1 [aw=hhweight], n(5)
egen qwealth=max(hhwealth), by(hhid)

la var qwealth "Household wealth quintile"

la def Lqwealth 1 "Poorest" 2 "Poor" 3 "Middle" 4 "Richer" 5 "Richest"

la val qwealth Lqwealth

*Weights
*HH weight at age 5/6
replace chweight=hhweight if age==5 | age==6

save "Data & Do/hl ch 2018.dta", replace


*Family composition

use "Data & Do/hl ch 2018.dta", clear

drop indid

keep if hl14!=.

*Generate an individual id of the mother
gen indid=hhid+string(hl14, "%02.0f")

collapse (min) yng_age=age, by(indid)

save "Data & Do/mere_all_ch 2018.dta", replace


use "Data & Do/hl ch 2018.dta", clear

*Youngest ECE eligible attends?
keep if ece!=. & rd_group!=.
drop indid

*Generate an individual id of the mother
gen indid=hhid+string(hl14, "%02.0f")

*Take data from youngest if multiple
sort indid rd_group birth_date

*Youngest will be last
bysort indid rd_group: keep if _n==_N
*Drops 88 obs.

*Unique?
isid rd_group indid

*Keep 
keep ece age_d31 days_d31 rd_group /* hrs_ece */ indid
rename * ch_*_
rename ch_indid_ indid

*Reshape 
reshape wide ch_ece_ ch_age_d31 ch_days_d31 /* ch_hrs_ece*/ , j(ch_rd_group) i(indid) 


save "Data & Do/mere_ch 2018.dta", replace

*ALT

use "Data & Do/hl ch 2018.dta", clear

*Youngest ECE eligible attends?
keep if ece_z!=. & rd_group!=.
drop indid

*Generate an individual id of the mother
gen indid=hhid+string(hl14, "%02.0f")

*Take data from youngest if multiple
sort indid rd_group birth_date

*Youngest will be last
bysort indid rd_group: keep if _n==_N
*Drops 89 obs.

*Unique?
isid rd_group indid


*Keep 
keep ece_z age_d31 days_d31 rd_group /* hrs_ece */ indid
rename * ch_*_z_
rename *z_z* *z*
rename ch_indid_ indid

*Reshape 
reshape wide ch_ece_z_ ch_age_d31 ch_days_d31 /* ch_hrs_ece*/, j(ch_rd_group) i(indid) 

save "Data & Do/mere_ch_z 2018.dta", replace


*Merge into household file
use "Data & Do/hl ch 2018.dta", clear

*Merging based on mother's/guardian's line
merge 1:1 indid using "Data & Do/mere_all_ch 2018.dta"
tabu _merge 
tabu _merge hl4, miss
drop _merge

*Merging based on mother's/guardian's line
merge 1:1 indid using "Data & Do/mere_ch 2018.dta"
tabu _merge 
tabu _merge hl4, miss
*Some non-matched
drop if _merge==2
drop _merge

*Merging based on mother's/guardian's line
merge 1:1 indid using "Data & Do/mere_ch_z 2018.dta"
tabu _merge 
tabu _merge hl4, miss
*Some non-matched
drop if _merge==2
drop _merge


*Keep for combining

keep yng_age ece /* hrs_ece */ age_d31 rd_group ch_ece* /* ch_hrs_ece* */  sit educ sex marital age urban hhid indid ///
chweight hhweight birth? qwealth visit? region nuclear ///
 melevel felevel year ch_days_d31* ch_age_d31* self_emp wage_emp helevel

foreach num of numlist 4/5 { 
 
la var ch_ece_z_`num' "Child in ECE alt. (age `num')"
la var ch_ece_`num' "Child in ECE (age `num')"
*la var ch_hrs_ece_`num' "Child hours in ECE (age `num')"
la var ch_age_d31_`num' "Age of child Dec. 31 (age `num')"
la var ch_days_d31_`num' "Days from cutoff of child (age `num')"

}

save "Data & Do/combo 2018.dta", replace
