/* Algeria FLFP ECE
MICS combine 2006 2012 
Version 7 CK
Original: January 27, 2021
Updated: 2023.03.17 (WBER revision)
Moundir Lassassi and Caroline Krafft
*/

use "Data & Do/combo 2006.dta", clear
append using "Data & Do/combo 2012.dta"
append using "Data & Do/combo 2018.dta"

la var year "Year"

*Check
bysort year: sum *


***Labels
*Regions

la def Lregion 1 "North Center" 2 "North East" 3 "North West" ///
4 "High Central Plains" 5 "High East Plains" 6 "High West Plains" ///
7 "South"

la val region Lregion
la var region "Region"

recode urban (2=0)
la def Lurban 0 "Rural" 1 "Urban"

la val urban Lurban
la var urban "Residence"

la var sex "Sex"
la def Lsex 1 "Male" 2 "Female"
la val sex Lsex

*Age of youngest
recode yng_age (0/2 = 1 "0-2") (3/5=2 "3-5") ///
(6/11 =3 "6-11") (12/17 =4 "12-17"), gen(agecat_young) label(Lagecat_young)

replace agecat_young=0 if marital==1  & agecat_young==. 
replace agecat_young=5 if marital>=2 & marital<=4 & agecat_young==.

la def Lagecat_young 0 "Single" 5 "Married no children", modify
la var agecat_young "Age of youngest child"
	   
*Age group	   
recode age (0/4=1)(5/9=2)(10/14=3)(15/19=4)(20/24=5)(25/29=6)(30/34=7)(35/39=8)(40/44=9) ///
           (45/49=10) (50/54=11) (55/59=12) (60/64=13) (65/69=14) (70/74=15) (75/max=16), gen(agegrp2)

label define Lagegrp2   ///         
	1 "0-4" ///
    2 "5-9" /// 
    3 "10-14" ///
    4 "15-19" ///
    5 "20-24" ///
    6 "25-29" ///
    7 "30-34" ///
    8 "35-39" ///
    9 "40-44" ///
    10 "45-49" ///
    11 "50-54" ///
    12 "55-59" /// 
    13 "60-64" ///
    14 "65-69" ///
    15 "70-74" ///
    16 "75+"

la val agegrp2 Lagegrp2

label variable agegrp2 "Age (Sixteen groups)"

la var sit "Labour market status"
la def Lsit 1 "Employed" 2 "Unemployed" 3 "Out of LF", modify
la val sit Lsit

gen lfp=(sit==2 | sit==1) if sit!=. 
gen unemp=(sit==2) if lfp==1
gen unemp_pop=(sit==2) if sit!=.
gen emp=(sit==1) if sit!=. 

la var lfp "Labor force participation"
la var unemp "Unemployment rate" 
la var unemp_pop "Unemployment to pop."
la var emp "Employment"

*Percentage

foreach var of varlist ece ch_ece* lfp emp unemp unemp_pop self_emp wage_emp {
	replace `var'=`var'*100
}


*Running and cutoff
la def Lqual 0 "Below cutoff" 1 "Above cutoff", modify

*Into weeks
foreach num of numlist 4/5 {
gen ch_weeks_d31_`num'=ceil(ch_days_d31_`num'/7)
la var ch_weeks_d31_`num' "Age in weeks from cutoff (age `num')"

gen ch_weeks_d31_z_`num'=ceil(ch_days_d31_z_`num'/7)
la var ch_weeks_d31_z_`num' "Age in weeks from cutoff (age `num')"


*Above/below cutoff
gen qual_`num'=(ch_weeks_d31_`num'>=0) if ch_weeks_d31_`num'<.

la var qual_`num' "Above cutoff (age `num')"

la val qual_`num' Lqual

gen qual_z_`num'=(ch_weeks_d31_z_`num'>=0) if ch_weeks_d31_z_`num'<.

la var qual_z_`num' "Above cutoff (age `num')"

la val qual_z_`num' Lqual

}

la def Lpeduc 1 "None" 2 "Primary" 3 "Middle" 4 "Secondary" 5 "Tertiary"  6 "Absent/Missing"

replace melevel=melevel+1 if year==2018 & melevel<5
replace felevel=felevel+1 if year==2018 & felevel<5
replace helevel=helevel+1 if year==2018 & helevel<5

recode melevel (0=1) (7=6) (9=6) (.=6)
recode felevel (0=1) (7=6) (9=6) (.=6)
recode helevel (0=1) (9=6) (.=6)

la val melevel Lpeduc
la val felevel Lpeduc
la val helevel Lpeduc

la var melevel "Mother's education level"
la var felevel "Father's education level"

 
*Dummies for covs
tabu educ, gen(ed_)
tabu agegrp2, gen(age_)
tabu marital, gen(mar_)
tabu region, gen(reg_)
tabu helevel, gen(hed_)

save "Data & Do/combo 2006 2012 2018 father.dta", replace
