/* Algeria FLFP ECE
Regression Discontinuity
Version 11 CK
Original: November 20, 2019
Updated: 2023.01.13 (WBER Revision)
Moundir Lassassi and Caroline Krafft
*/

use "Data & Do/combo 2006 2012 2018.dta", clear

*Graph scheme
set scheme s1mono

*Clear estimates 
estimates clear


sort indid
isid indid

set seed 28934723


*****
*Graphs
*****


*****
*ECE
*****

*Linear 
foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

local vtext =  "`time' `: label (rd_group) `= + `group'''"

rdplot ch_ece_`group' ch_weeks_d31_`group' if year==`time', p(1) c(0) weights(hhweight) ci(95) shade nbins(6 6) graph_options(title("`vtext'", size(3.5)) xtitle("Weeks older than Dec. 31 cutoff") ytitle("Pre-primary (%)") xlabel(-20(10)20) ylabel(0(20)80) legend(off)) 

graph save "Graphs and Tables/rdd_yng_ece_`group'_`time'", replace
graph export "Graphs and Tables/rdd_yng_ece_`group'_`time'.png", replace width(3000)


}
}

graph combine "Graphs and Tables/rdd_yng_ece_4_2006" ///
"Graphs and Tables/rdd_yng_ece_4_2012" ///
"Graphs and Tables/rdd_yng_ece_4_2018" ///
"Graphs and Tables/rdd_yng_ece_5_2006" ///
 "Graphs and Tables/rdd_yng_ece_5_2012" ///
 "Graphs and Tables/rdd_yng_ece_5_2018", row(2) 

graph save "Graphs and Tables/rdd_ece_combo.gph", replace
graph export "Graphs and Tables/rdd_ece_combo.png", replace width(3000)



*Intercept only
foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

local vtext =  "`time' `: label (rd_group) `= + `group'''"

rdplot ch_ece_`group' ch_weeks_d31_`group' if year==`time', p(0) c(0) weights(hhweight) ci(95) shade nbins(6 6) graph_options(title("`vtext'", size(3.5)) xtitle("Weeks older than Dec. 31 cutoff") ytitle("Pre-primary (%)") xlabel(-20(10)20) ylabel(0(20)80) legend(off)) 

graph save "Graphs and Tables/rdd_yng_i_ece_`group'_`time'", replace
graph export "Graphs and Tables/rdd_yng_i_ece_`group'_`time'.png", replace width(3000)


}
}

graph combine "Graphs and Tables/rdd_yng_i_ece_4_2006" ///
"Graphs and Tables/rdd_yng_i_ece_4_2012" ///
"Graphs and Tables/rdd_yng_i_ece_4_2018" ///
"Graphs and Tables/rdd_yng_i_ece_5_2006" ///
 "Graphs and Tables/rdd_yng_i_ece_5_2012" ///
 "Graphs and Tables/rdd_yng_i_ece_5_2018", row(2) 

graph save "Graphs and Tables/rdd_i_ece_combo.gph", replace
graph export "Graphs and Tables/rdd_i_ece_combo.png", replace width(3000)


*Quadratic
foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

local vtext =  "`time' `: label (rd_group) `= + `group'''"

rdplot ch_ece_`group' ch_weeks_d31_`group' if year==`time', p(2) c(0) weights(hhweight) ci(95) shade nbins(6 6) graph_options(title("`vtext'", size(3.5)) xtitle("Weeks older than Dec. 31 cutoff") ytitle("Pre-primary (%)") xlabel(-20(10)20) ylabel(0(20)80) legend(off)) 

graph save "Graphs and Tables/rdd_yng_q_ece_`group'_`time'", replace
graph export "Graphs and Tables/rdd_yng_q_ece_`group'_`time'.png", replace width(3000)


}
}

graph combine "Graphs and Tables/rdd_yng_q_ece_4_2006" ///
"Graphs and Tables/rdd_yng_q_ece_4_2012" ///
"Graphs and Tables/rdd_yng_q_ece_4_2018" ///
"Graphs and Tables/rdd_yng_q_ece_5_2006" ///
 "Graphs and Tables/rdd_yng_q_ece_5_2012" ///
 "Graphs and Tables/rdd_yng_q_ece_5_2018", row(2) 

graph save "Graphs and Tables/rdd_q_ece_combo.gph", replace
graph export "Graphs and Tables/rdd_q_ece_combo.png", replace width(3000)



*****
*Emp: Optimal polynomial
*****


foreach var of varlist emp {
foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

*Intercept
reg `var' i.qual_`group' if year==`time' [aw=hhweight]

estimates store fit_i_`var'_`group'_`time'

estat ic

estadd scalar aic=el(r(S),1,5)

*Linear
reg `var' i.qual_`group'##c.ch_weeks_d31_`group' if year==`time' [aw=hhweight]

estimates store fit_l_`var'_`group'_`time'

estat ic

estadd scalar aic=el(r(S),1,5)

*Quadratic
reg `var' i.qual_`group'##c.ch_weeks_d31_`group'##c.ch_weeks_d31_`group' if year==`time' [aw=hhweight]

estimates store fit_q_`var'_`group'_`time'

estat ic

estadd scalar aic=el(r(S),1,5)


}
}
}


*Age four 
esttab fit_*_4_* using "Graphs and tables/fit_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(N r2 r2_a aic, fmt(%9.0f %9.3f %9.3f %9.0f) label("N (obs.)" "R-sq." "Adj. R-sq." "AIC")) noomit nobase label mlabel("Emp.  2006" "Emp.  2006" "Emp.  2006" "Emp.  2012" "Emp.  2012" "Emp.  2012" "Emp.  2018" "Emp.  2018" "Emp.  2018")

*Age five
esttab fit_*_5_* using "Graphs and tables/fit_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(N r2 r2_a aic, fmt(%9.0f %9.3f %9.3f %9.0f) label("N (obs.)" "R-sq." "Adj. R-sq." "AIC")) noomit nobase label  mlabel("Emp.  2006" "Emp.  2006" "Emp.  2006" "Emp.  2012" "Emp.  2012" "Emp.  2012" "Emp.  2018" "Emp.  2018" "Emp.  2018")



******
*Employment plot - intercept only
******

foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

local vtext =  "`time' `: label (rd_group) `= + `group'''"

rdplot emp ch_weeks_d31_`group' if year==`time', p(0) c(0) fuzzy(ch_ece_`group') weights(hhweight) ci(95) shade nbins(6 6) graph_options(title("`vtext'", size(3.5)) xtitle("Weeks older than Dec. 31 cutoff") ytitle("Employment (%)") xlabel(-20(10)20) ylabel(0(5)30) legend(off) plotregion(margin(none))) 

graph save "Graphs and Tables/rdd_yng_emp_`group'_`time'", replace
graph export "Graphs and Tables/rdd_yng_emp_`group'_`time'.png", replace width(3000)


}
}

graph combine "Graphs and Tables/rdd_yng_emp_4_2006" ///
"Graphs and Tables/rdd_yng_emp_4_2012" ///
"Graphs and Tables/rdd_yng_emp_4_2018" ///
"Graphs and Tables/rdd_yng_emp_5_2006" ///
 "Graphs and Tables/rdd_yng_emp_5_2012" ///
 "Graphs and Tables/rdd_yng_emp_5_2018", row(2) 

graph save "Graphs and Tables/rdd_emp_combo.gph", replace
graph export "Graphs and Tables/rdd_emp_combo.png", replace width(3000)




******
*Employment plot - linear
******

foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

local vtext =  "`time' `: label (rd_group) `= + `group'''"

rdplot emp ch_weeks_d31_`group' if year==`time', p(1) c(0) fuzzy(ch_ece_`group') weights(hhweight) ci(95) shade nbins(6 6) graph_options(title("`vtext'", size(3.5)) xtitle("Weeks older than Dec. 31 cutoff") ytitle("Employment (%)") ylabel(0(5)30) legend(off) plotregion(margin(none))) 

graph save "Graphs and Tables/rdd_l_yng_emp_`group'_`time'", replace
graph export "Graphs and Tables/rdd_l_yng_emp_`group'_`time'.png", replace width(3000)


}
}

graph combine "Graphs and Tables/rdd_l_yng_emp_4_2006" ///
"Graphs and Tables/rdd_l_yng_emp_4_2012" ///
"Graphs and Tables/rdd_l_yng_emp_4_2018" ///
"Graphs and Tables/rdd_l_yng_emp_5_2006" ///
 "Graphs and Tables/rdd_l_yng_emp_5_2012" ///
 "Graphs and Tables/rdd_l_yng_emp_5_2018", row(2) 

graph save "Graphs and Tables/rdd_l_emp_combo.gph", replace
graph export "Graphs and Tables/rdd_l_emp_combo.png", replace width(3000)





******
*Employment plot - quadratic
******

foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

local vtext =  "`time' `: label (rd_group) `= + `group'''"

rdplot emp ch_weeks_d31_`group' if year==`time', p(2) c(0) fuzzy(ch_ece_`group') weights(hhweight) ci(95) shade nbins(6 6) graph_options(title("`vtext'", size(3.5)) xtitle("Weeks older than Dec. 31 cutoff") ytitle("Employment (%)") ylabel(0(5)30) legend(off) plotregion(margin(none))) 

graph save "Graphs and Tables/rdd_q_yng_emp_`group'_`time'", replace
graph export "Graphs and Tables/rdd_q_yng_emp_`group'_`time'.png", replace width(3000)


}
}

graph combine "Graphs and Tables/rdd_q_yng_emp_4_2006" ///
"Graphs and Tables/rdd_q_yng_emp_4_2012" ///
"Graphs and Tables/rdd_q_yng_emp_4_2018" ///
"Graphs and Tables/rdd_q_yng_emp_5_2006" ///
 "Graphs and Tables/rdd_q_yng_emp_5_2012" ///
 "Graphs and Tables/rdd_q_yng_emp_5_2018", row(2) 

graph save "Graphs and Tables/rdd_q_emp_combo.gph", replace
graph export "Graphs and Tables/rdd_q_emp_combo.png", replace width(3000)



*****
*Density
*****

**rddensity !version 2.3 2021-02-28
*Tempermental with loop, run non-loop first

rddensity ch_weeks_d31_4 if year==2006, p(1) c(0) kernel(uniform) all plot histl_opt(lcolor(gs7%70) fcolor(gs7%70)) cirl_opt(fcolor(gs7%70)) esll_opt(lcolor(gs7)) histr_opt(lcolor(gs1%70) fcolor(gs1%70)) cirr_opt(fcolor(gs1%70)) eslr_opt(lcolor(gs1) fcolor(gs1)) 

*Loop

foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

local vtext =  "`time' `: label (rd_group) `= + `group'''"
di "`vtext' "
rddensity ch_weeks_d31_`group' if year==`time', p(1) c(0) kernel(uniform) all h(27 27) plot plot_n(27 27)  plot_range(-27 27) plot_grid(es) graph_opt(xlabel(-30(10)30) ylabel(0(.01).03) plotregion(margin(none)) xtitle("Weeks older than Dec. 31 cutoff") title("`vtext'") legend(off)) nobinomial hist_n(25 27) histl_opt(lcolor(gs7%70) fcolor(gs7%70)) cirl_opt(fcolor(gs7%70)) esll_opt(lcolor(gs7)) histr_opt(lcolor(gs1%70) fcolor(gs1%70)) cirr_opt(fcolor(gs1%70)) eslr_opt(lcolor(gs1) fcolor(gs1)) 


gr_edit yaxis1.title.text.Arrpush Proportion

graph save "Graphs and Tables/histogram `group' `time'.gph", replace 
graph export "Graphs and Tables/histogram  `group' `time'.png", replace width(3000)

}
}


graph combine "Graphs and Tables/histogram 4 2006.gph" "Graphs and Tables/histogram 5 2006.gph" "Graphs and Tables/histogram 4 2012.gph" "Graphs and Tables/histogram 5 2012.gph" "Graphs and Tables/histogram 4 2018.gph" "Graphs and Tables/histogram 5 2018.gph", row(3)

graph save "Graphs and Tables/histogram.gph", replace 
graph export "Graphs and Tables/histogram.png", replace width(3000)





*****
*RDD-estimation
*****


foreach var of varlist emp {
foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

*Main (intercept)
rdrobust `var' ch_weeks_d31_`group' if year==`time', fuzzy(ch_ece_`group') c(0) weights(hhweight) p(0) q(1) kernel(uni) all h(27) b(27) 

estimates store rd_27_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))



*Half bandwidth
rdrobust `var' ch_weeks_d31_`group' if year==`time', fuzzy(ch_ece_`group') c(0) weights(hhweight) p(0) q(1) kernel(uni) all h(13) b(13)

estimates store rd_13_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))


*p=1 linear
rdrobust `var' ch_weeks_d31_`group' if year==`time', fuzzy(ch_ece_`group') c(0) weights(hhweight) p(1) q(2) kernel(uni) all h(27) b(27) 

estimates store rd_27l_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))


*p=2 quadratic
rdrobust `var' ch_weeks_d31_`group' if year==`time', fuzzy(ch_ece_`group') c(0) weights(hhweight) p(2) q(3) kernel(uni) all h(27) b(27)  

estimates store rd_27q_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))


*Controls
rdrobust `var' ch_weeks_d31_`group' if year==`time', fuzzy(ch_ece_`group') c(0) weights(hhweight) p(0) q(1) kernel(uni) all h(27) b(27)  covs(ed_* age_* mar_* nuclear urban reg_*)

estimates store rd_27c_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))


*Nuclear
di "Nuclear age `group' `time'"
rdrobust `var' ch_weeks_d31_`group' if year==`time' & nuclear==1, fuzzy(ch_ece_`group') c(0) weights(hhweight) p(0) q(1) kernel(uni) all h(27) b(27)  

estimates store rd_nuc_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))


*Extended

di "Extended age `group' `time'"
rdrobust `var' ch_weeks_d31_`group' if year==`time' & nuclear==0, fuzzy(ch_ece_`group') c(0) weights(hhweight) p(0) q(1) kernel(uni) all h(27) b(27)  

estimates store rd_ext_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))


*With zeroes for primary
rdrobust `var' ch_weeks_d31_z_`group' if year==`time', fuzzy(ch_ece_z_`group') c(0) weights(hhweight) p(0) q(1) kernel(uni) all h(27) b(27) 

estimates store rd_z_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))


}
}
}

foreach var of varlist self_emp wage_emp {
foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

*Main (intercept)
di "`var' `group' `time' "

rdrobust `var' ch_weeks_d31_`group' if year==`time', fuzzy(ch_ece_`group') c(0) weights(hhweight) p(0) q(1) kernel(uni) all h(27) b(27) 

estimates store rd_type_`var'_`group'_`time'

*Storing first stage
estadd scalar conv_T=e(tau_T_cl)
estadd scalar conv_T_se=e(se_tau_T_cl)
estadd scalar conv_T_p=2*normal(-abs(e(tau_T_cl)/e(se_tau_T_cl)))
estadd scalar bc_T=e(tau_T_bc)
estadd scalar bc_T_se=e(se_tau_T_cl)
estadd scalar bc_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_cl)))
estadd scalar bcrb_T=e(tau_T_bc) 
estadd scalar bcrb_T_se=e(se_tau_T_rb)
estadd scalar bcrb_T_p=2*normal(-abs(e(tau_T_bc)/e(se_tau_T_rb)))


}
}
}



*******
*Output
*******

**Note, first-stage sig. stars done in Excel

*Age four main
esttab rd_27_*_4_* using "Graphs and tables/RDD_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five main
esttab rd_27_*_5_* using "Graphs and tables/RDD_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age four smaller bw
esttab rd_13_*_4_* using "Graphs and tables/RDD_13_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five smaller bw
esttab rd_13_*_5_* using "Graphs and tables/RDD_13_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age four linear 
esttab rd_27l_*_4_* using "Graphs and tables/RDDi_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five linear
esttab rd_27l_*_5_* using "Graphs and tables/RDDi_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age four quadratic
esttab rd_27q_*_4_* using "Graphs and tables/RDDq_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five quadratic
esttab rd_27q_*_5_* using "Graphs and tables/RDDq_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))


*Age four covs 
esttab rd_27c_*_4_* using "Graphs and tables/RDDc_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five covs
esttab rd_27c_*_5_* using "Graphs and tables/RDDc_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))


*Age four nuclear/ext 
esttab rd_nuc_*_4_* rd_ext_*_4_* using "Graphs and tables/RDDnuc_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five nuclear/ext
esttab rd_nuc_*_5_* rd_ext_*_5_* using "Graphs and tables/RDDnuc_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age four wage 
esttab rd_type_wage_emp_4_* using "Graphs and tables/RDD_wage_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five wage
esttab rd_type_wage_emp_5_* using "Graphs and tables/RDD_wage_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age four self 
esttab rd_type_self_emp_4_* using "Graphs and tables/RDD_self_age4.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five self
esttab rd_type_self_emp_5_* using "Graphs and tables/RDD_self_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))

*Age five zeroes for primary
esttab rd_z_emp_5_* using "Graphs and tables/RDD_z_age5.csv", replace cells(b(star fmt(%9.3f)) se(par)) stats(conv_T conv_T_se bc_T bc_T_se bcrb_T bcrb_T_se N N_r N_l conv_T_p bc_T_p bcrb_T_p, fmt(%9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.0g %9.0g %9.0g ) label("First conventional" " " "First bias-corrected" " " "First robust" " ""N (Obs.)" "N right" "N left" "p-val conventional" "p-val bias-corrected" "p-val robust") layout("@" "(@)" "@" "(@)" "@" "(@)" "@" "@" "@"))


******
*RDD-balance
******


foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {


iebaltab ed_* age_4 age_5 age_6 age_7 age_8 age_9 age_10 age_11 age_12 age_13 age_14 mar_* nuclear urban reg_* hed_* if year==`time' [aw=hhweight], grpvar(qual_`group') save("Graphs and tables/balance_`group'_`time'") replace starlevels(.05 .01 .001) rowlabel("ed_1 No education @ ed_2 Primary @ ed_3 Middle @ed_4 Secondary @ ed_5 Tertiary @ age_4 Age 15-19 @ age_5 Age 20-24 @ age_6 Age 25-29 @ age_7 Age 30-34 @ age_8 Age 35-39 @ age_9 Age 40-45 @ age_10 Age 45-49 @ age_11 Age 50-54 @ age_12 Age 55-59 @ age_13 Age 60-64 @ age_14 Age 65-69 @ mar_1 Single @ mar_2 Marired @ mar_3 Divorced @ mar_4 Widowed @ nuclear Nuclear household @ urban Urban @ reg_1 North Center @ reg_2 North East @ reg_3 North West @ reg_4 High Central Plains @ reg_5 High East Plains @ reg_6 High West Plains @ reg_7 South @ hed_1 No education @ hed_2 Primary @ hed_3 Middle @ hed_4 Secondary @ hed_5 Tertiary @ hed_6 Missing/DK") ftest fmissok

}
}

******
*RDD-2SLS-regressions 
******

foreach var of varlist emp {
foreach group of numlist 4/5 {
foreach time of numlist 2006 2012 2018 {

di "`var' " "`group' " "`time'"

***Intercept only 

*First stage
regress ch_ece_`group' i.qual_`group' ///
 if year==`time' & `var'!=. [aw=hhweight], vce(robust)

estimates store first_`var'_iv_i_`group'_`time'  


ivregress 2sls `var' ///
(ch_ece_`group' = i.qual_`group') ///
 if year==`time' [aw=hhweight], first vce(robust)

estimates store second_`var'_iv_i_`group'_`time'  

*Test of H0: exogeneous
estat endogenous, forceweights
*P-values from tests
estadd scalar p_chi=r(p_r_score)
estadd scalar p_regF=r(p_regF)

*Test of first stage
estat firststage

*Partial R-square, F, p-value of F
estadd scalar p_r2=el(r(singleresults),1,3)
estadd scalar F_val=el(r(singleresults),1,4)
estadd scalar p_val=el(r(singleresults),1,7)
  
  
  
***Intercept & linear 

*First stage
regress ch_ece_`group' i.qual_`group' c.ch_weeks_d31_`group' ///
 if year==`time' & `var'!=. [aw=hhweight], vce(robust)

estimates store first_`var'_iv_li_`group'_`time'  


ivregress 2sls `var' ///
(ch_ece_`group' = i.qual_`group' c.ch_weeks_d31_`group') ///
 if year==`time' [aw=hhweight], first vce(robust)

estimates store second_`var'_iv_li_`group'_`time'  

*Test of H0: exogeneous
estat endogenous, forceweights
*P-values from tests
estadd scalar p_chi=r(p_r_score)
estadd scalar p_regF=r(p_regF)

*Test of first stage
estat firststage

*Partial R-square, F, p-value of F
estadd scalar p_r2=el(r(singleresults),1,3)
estadd scalar F_val=el(r(singleresults),1,4)
estadd scalar p_val=el(r(singleresults),1,7)
  


  
  
***Both linear 

*First stage
regress ch_ece_`group' i.qual_`group' c.ch_weeks_d31_`group' ///
 if year==`time' & `var'!=. [aw=hhweight], vce(robust)

estimates store first_`var'_iv_l_`group'_`time'  


ivregress 2sls `var' c.ch_weeks_d31_`group' ///
(ch_ece_`group' = i.qual_`group' ) ///
 if year==`time' [aw=hhweight], first vce(robust)

estimates store second_`var'_iv_l_`group'_`time'  

*Test of H0: exogeneous
estat endogenous, forceweights
*P-values from tests
estadd scalar p_chi=r(p_r_score)
estadd scalar p_regF=r(p_regF)

*Test of first stage
estat firststage

*Partial R-square, F, p-value of F
estadd scalar p_r2=el(r(singleresults),1,3)
estadd scalar F_val=el(r(singleresults),1,4)
estadd scalar p_val=el(r(singleresults),1,7)  
  

}
}
}



esttab first_*_iv_*_4_* ///
using "Graphs and tables/first_IV_4.csv", cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N r2, fmt(%9.0g %9.3g) label("N (Obs.)" "R-sq.")) label  ///
 nobase ///
 modelwidth(9) ///
noomit nobase ///
 replace
 
 
esttab first_*_iv_*_5_* ///
using "Graphs and tables/first_IV_5.csv", cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N r2, fmt(%9.0g %9.3g) label("N (Obs.)" "R-sq.")) label  ///
 nobase ///
 modelwidth(9) ///
 noomit nobase ///
 replace


 
esttab second_*_iv_*_4_* ///
using "Graphs and tables/second_IV_4.csv", cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N r2 p_chi p_regF p_r2 F_val p_val, fmt(%9.0g %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) label("N (Obs.)" "R-sq." "p-val. for chi H0: exog." "p-val. for F-test H0: exog." "Partial r-sq." "F-stat. first" "p-val F test")) label  ///
 nobase ///
 modelwidth(9) ///
 noomit nobase ///
 replace

esttab second_*_iv_*_5_* ///
using "Graphs and tables/second_IV_5.csv", cells(b(star fmt(%9.3f)) se(par))  ///     
 stats(N r2 p_chi p_regF p_r2 F_val p_val, fmt(%9.0g %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f) label("N (Obs.)" "R-sq." "p-val. for chi H0: exog." "p-val. for F-test H0: exog." "Partial r-sq." "F-stat. first" "p-val F test")) label  ///
 nobase ///
 modelwidth(9) ///
 noomit nobase ///
 replace




